Crate cable_tunnel_server_common

Crate cable_tunnel_server_common 

Common components for webauthn-rs’ caBLE tunnel server.

Important: this library is an internal implementation detail of webauthn-rs’ caBLE tunnel server, and has no guarantees of API stability whatsoever. It is not intended for use outside of that context.

Structs

BackendClientOptions
CablePath
Path for caBLE WebSocket tunnel protocol.
ServerTransportProtocol

Enums

CableMethod
Method for caBLE WebSocket tunnel protocol.
Router
HTTP router for a caBLE WebSocket tunnel server.
TlsConfigError

Constants

CABLE_CONNECT_PATH
CABLE_NEW_PATH
CABLE_ROUTING_ID_HEADER
MAX_URL_LENGTH

Statics

CABLE_PROTOCOL

Functions

copy_request_empty_body
Create a copy of an existing HTTP Request, discarding the body.
copy_response_empty_body
Create a copy of an existing HTTP Response, discarding the body.
empty_response
Make a Response with a given StatusCode and empty body.
parse_duration_secs
Parses a duration as a number of seconds from a string.
parse_hex
Parses a Base-16 encoded string.
run_server
Run a HTTP server for the caBLE WebSocket tunnel.
setup_logging
Sets up logging for cable-tunnel-server binaries.

Type Aliases

RoutingId
TunnelId