Common components for webauthn-rs’ caBLE tunnel server.
Important: this library is an internal implementation detail of webauthn-rs’ caBLE tunnel server, and has no guarantees of API stability whatsoever. It is not intended for use outside of that context.
Structs
- Backend
Client Options - Cable
Path - Path for caBLE WebSocket tunnel protocol.
- Server
Transport Protocol
Enums
- Cable
Method - Method for caBLE WebSocket tunnel protocol.
- Router
- HTTP router for a caBLE WebSocket tunnel server.
- TlsConfig
Error
Constants
Statics
Functions
- copy_
request_ empty_ body - Create a copy of an existing HTTP Request, discarding the body.
- copy_
response_ empty_ body - Create a copy of an existing HTTP Response, discarding the body.
- empty_
response - Make a Response with a given StatusCode and empty body.
- parse_
duration_ secs - Parses a duration as a number of seconds from a string.
- parse_
hex - Parses a Base-16 encoded string.
- run_
server - Run a HTTP server for the caBLE WebSocket tunnel.
- setup_
logging - Sets up logging for cable-tunnel-server binaries.